<?php

namespace Survey\Employee\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Survey\Employee\Interfaces\EmployeeRepositoryInterface;

class EmployeePublicController extends BaseController
{
    // use EmployeeWorkflow;

    /**
     * Constructor.
     *
     * @param type \Survey\Employee\Interfaces\EmployeeRepositoryInterface $employee
     *
     * @return type
     */
    public function __construct(EmployeeRepositoryInterface $employee)
    {
        $this->repository = $employee;
        parent::__construct();
    }

    /**
     * Show employee's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $employees = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->setMetaTitle(trans('employee::employee.names'))
            ->view('employee::public.employee.index')
            ->data(compact('employees'))
            ->output();
    }


    /**
     * Show employee.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $employee = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->setMetaTitle($employee->name . trans('employee::employee.name'))
            ->view('employee::public.employee.show')
            ->data(compact('employee'))
            ->output();
    }

}
